@@ -2166,7 +2166,7 @@ int main( int argc, char *argv[] )
 	printf("%14s = %zu\n", "page size", page_size);
 	trace_space = info->space;
 	printf("%14s = %u (%s)\n", "trace space", trace_space, trace_space_name[trace_space]);
-	printf(info->uname);
+	printf("%s", info->uname);
 	printf("\n");
 	
 	if (fstat(fd, &st)) {
