@@ -79,6 +79,14 @@ __BEGIN_TEMPLATE_ARGS__
 __END_TEMPLATE_ARGS__
 __TEMPLATE_ARGS_AUTOFILL__32
 
+#ifdef __GNUC__
+#  define FUT_UNLIKELY(expr) (__builtin_expect((expr),0))
+#  define FUT_LIKELY(expr) (__builtin_expect(!!(expr),1))
+#else
+#  define FUT_UNLIKELY(expr) (expr)
+#  define FUT_LIKELY(expr) (expr)
+#endif
+
 #define FUT_CODE(CODE, n) ((((unsigned long)(CODE))<<8) | ((n) + 1))
 #define FUT_SIZE(n) (sizeof(fxt_trace_user_raw_t)+(n)*sizeof(long))
 #define FUT_STRLEN(s) ((strlen(s)+sizeof(long)-1)/sizeof(long))
@@ -95,7 +103,7 @@ __BEGIN_TEMPLATE__
 	} while (0)
 
 #define FUT_RAW_PROBE__NUMBER__(CODE__DECLARE_ARGS__) do {		\
-		if(fut_active) {					\
+		if(FUT_UNLIKELY(fut_active)) {				\
 			FUT_RAW_ALWAYS_PROBE__NUMBER__(CODE__CALL_ARGS__); \
 		}							\
 	} while (0)
@@ -116,7 +124,7 @@ __BEGIN_TEMPLATE__
 	} while (0)
 
 #define FUT_RAW_PROBE__NUMBER__STR(CODE__DECLARE_ARGS__,S) do {		\
-		if(fut_active) {					\
+		if(FUT_UNLIKELY(fut_active)) {				\
 			FUT_RAW_ALWAYS_PROBE__NUMBER__STR(CODE__CALL_ARGS__,S); \
 		}							\
 	} while (0)
@@ -134,7 +142,7 @@ __END_TEMPLATE__
 	} while (0)
 
 #define FUT_RAW_PROBESTR(CODE,S) do {					\
-		if(fut_active) {					\
+		if(FUT_UNLIKELY(fut_active)) {				\
 			FUT_RAW_ALWAYS_PROBESTR(CODE, S);		\
 		}							\
 	} while (0)
@@ -178,7 +186,7 @@ inline static void
 __attribute__((no_instrument_function))
 #endif
 FUT_RAW_PROBE(unsigned long code, ...) {
-	if(fut_active) {		
+	if(FUT_UNLIKELY(fut_active)) {		
 	int nb=(code&0xff)-1, orig_nb = nb;
         unsigned long *args=fut_getstampedbuffer(code, FUT_SIZE(nb));
 	va_list list;
@@ -205,14 +213,14 @@ __END_TEMPLATE_ARGS__
 
 __BEGIN_TEMPLATE__
 #define FUT_FULL_PROBE__NUMBER__(KEYMASK,CODE__DECLARE_ARGS__) do { \
-	if( KEYMASK & fut_active ) { \
+	if (FUT_UNLIKELY(KEYMASK & fut_active)) { \
                 FUT_RAW_ALWAYS_PROBE__NUMBER__(FUT_CODE(CODE, __NUMBER__)__CALL_ARGS__); \
         } \
 } while(0)
 
 __END_TEMPLATE__
 #define FUT_FULL_PROBESTR(KEYMASK,CODE,S) do { \
-	if (KEYMASK & fut_active) { \
+	if ( FUT_UNLIKELY(KEYMASK & fut_active)) { \
 		FUT_RAW_ALWAYS_PROBESTR(FUT_CODE(CODE, FUT_STRLEN(__s)),S); \
 	} \
 } while(0)
