@@ -1,5 +1,5 @@
 /*
-*  Copyright (C) 2004, 2011-2012, 2017 Samuel Thibault <samuel.thibault@ens-lyon.org>
+*  Copyright (C) 2004, 2011-2012, 2017, 2020 Samuel Thibault <samuel.thibault@ens-lyon.org>
  *
  * This program is free software ; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -360,9 +360,9 @@ extern pthread_spinlock_t fut_slot_lock;
 #endif
 
 unsigned long* __fut_record_event(fxt_trace_user_raw_t * rec, uint64_t stamp, unsigned long code);
-int fut_flush( char* filename, void *first_slot, void* next_slot, int record_flush_events );
+uint64_t fut_flush( const char* filename, void *first_slot, void* next_slot, int record_flush_events );
 void __fut_reset_pointers();
-extern unsigned int fut_nallocated;
+extern uint64_t fut_nallocated;
 
 #define i386_sync() __asm__ __volatile__("lock; addl $0,0(%%esp)" ::: "memory")
 #define x86_64_sync() __asm__ __volatile__("lock; addl $0,0(%%rsp)" ::: "memory")
