@@ -323,10 +323,11 @@ void dump64(fxt_blockev_t evs, int offset, int delta) {
 
 void usage(char *progname)
 {
-	printf("Usage: %s [-d] [-o] [-x] [-f record-file]\n\
+	printf("Dump the content of an FxT trace file\n\
+Usage: %s [-d] [-o] [-x] [-f record-file]\n\
 \n\
-	if -f is not given, look for TRACE_FILE environment variable, and\n\
-		if that is not given, read from \"" DEFAULT_TRACE_FILE "\".\n\
+if -f is not given, look for TRACE_FILE environment variable, and\n\
+if that is not given, read from \"" DEFAULT_TRACE_FILE "\".\n\
 \n\
         -d : dump mode (no trace interpretation)\n\
         -o : time offset (from begining)\n\
