@@ -97,7 +97,7 @@ int fkt_record_pids( fxt_t fxt, int fd )
 
 	if( !(dir = opendir("/proc")) )
 		{
-#ifndef __MINGW32__
+#if ! (defined(__MINGW32__) || defined(__APPLE__))
 		perror("opening /proc");
 		fprintf(stderr,"pids won't be recorded\n");
 #endif
